@@ -1,3 +1,4 @@
+from . import models
 from ..basics import *
 from ..callback.all import *
 from .augment import *
@@ -5,5 +6,4 @@ from .core import *
 from .data import *
 from .models.all import *
 from .learner import *
-from .models import *
 from .utils import *
